@@ -275,7 +275,7 @@ class PricePlan(NamedTuple):
     Represents a pricing plan for services.
     """
 
-    trial_period_days: str
+    trial_period_days: int
     """Number of days for the trial period. Can be zero."""
 
     trial_restrictions: Optional[str]
